<?php
/**
 * @package RSPageBuilder!
 * @copyright (C) 2016-2022 www.rsjoomla.com
 * @license GPL, http://www.gnu.org/licenses/gpl-3.0.html
 */

// No direct access.
defined('_JEXEC') or die('Restricted access');

use Joomla\CMS\Factory;
use Joomla\CMS\Plugin\CMSPlugin;
use Joomla\CMS\Plugin\PluginHelper;
use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Component\ComponentHelper;
use Joomla\CMS\Uri\Uri;

/**
 * RSForm! Pro RSFinder! Plugin.
 */
class plgRsfinderRspagebuilder extends CMSPlugin
{
    const EXTENSION = 'com_rspagebuilder';
	
	 /**
     * @var bool
     */
    protected $autoloadLanguage = true;

    protected function canRun() {
        // Check if the component exists and is enabled - in backend
        return (
            file_exists(JPATH_ADMINISTRATOR . '/components/'.self::EXTENSION.'/helpers/rspagebuilder.php') &&
            Factory::getApplication()->isClient('administrator') &&
            ComponentHelper::getComponent(self::EXTENSION, true)->enabled
        );
    }

    public function onRsfinderGetResults(&$tmp_results, $search, $limit, &$index)
    {
        if (!$this->canRun())
        {
            return;
        }

        // verify the index first, no need to continue if the limit is reached
        if ($index >= $limit)
        {
            return;
        }

        // Get the current User
        $user = Factory::getApplication()->getIdentity();
        $access  = $user->authorise('core.manage', self::EXTENSION) && $user->authorise('core.edit', self::EXTENSION);

        // if there is no access, skip the results
        if (!$access)
        {
            return;
        }

        $select_in = $this->params->get('searchList');

        // workaround for stored version
        if (is_string($select_in))
        {
            $select_in = explode(',', $select_in);
        }

        $output_results = array('dynamic' => array(), 'fixed' => array());

        // Get DBO.
        $db	= Factory::getContainer()->get('DatabaseDriver');
		
        if (in_array('pages', $select_in))
        {
            $query = $db->getQuery(true);
            $query->select(
                [
                    $db->qn('rspb.id', 'value'),
                    $db->qn('rspb.title', 'text'),
                ]
            )
                ->from($db->qn('#__rspagebuilder', 'rspb'))
                ->where($db->qn('rspb.title') . " LIKE ".$db->q('%'.$search.'%'))
                ->setLimit($limit);

            $db->setQuery($query);
            $results = $db->loadObjectList();

            if (!empty($results))
            {
                foreach($results as $result)
                {
                    // verify the index first
                    if ($index >= $limit)
                    {
                        break;
                    }

                    $output_result = array(
                        'title' => $this->escape($result->text).' '.Text::_('PLG_RSFINDER_RSPAGEBUILDER_EDIT_PAGE'),
                        'link'  => Uri::root().'administrator/index.php?option=com_rspagebuilder&task=page.edit&id='.$result->value,
                        'hits'  => 0
                    );

                    $output_results['dynamic'][] = $output_result;
                    $index ++;
                }
            }
        }
		
		
        if ($index < $limit && $this->params->get('options', 1))
        {
            $output_results['fixed'][] = array(
                'title' => Text::_('PLG_RSFINDER_RSPAGEBUILDER_OPTIONS_PAGE'),
                'link'  => Uri::root().'administrator/index.php?option=com_config&view=component&component=com_rspagebuilder',
                'hits'  => 0
            );
        }

        $tmp_results[] = $output_results;
    }

    protected function escape($string) {
        $string = (string) $string;
        return htmlentities($string, ENT_COMPAT, 'utf-8');
    }
}